@@ -1,7 +1,7 @@
 #############################################
 ##   Filename: algorithms.py
 ##
-##    Copyright (C) 2011 Marcus C. Newton
+##    Copyright (C) 2011 - 2022 Marcus C. Newton
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 import sys
 import wx
 import numpy
-from numpy.distutils.system_info import get_info
 import vtk
 from ..interface.render import wxVTKRenderWindowInteractor
 from vtk.util import numpy_support
@@ -636,7 +635,7 @@ class SequenceBaseMask(SequenceBase):
 			self.parent.mask = LoadArray(self.parent, self.mask_path)
 			self.parent.mask[:] = WrapArray(self.parent.mask).copy()
 		except:
-			msg = "Could not load array from: \n"+ mask_path + "\nPlease check the log."
+			msg = "Could not load array from: \n"+ self.mask_path + "\nPlease check the log."
 			self.MsgDlg(msg)
 			return True
 		else:
@@ -808,9 +807,9 @@ class Sequence_RAAR(SequenceBaseMask):
 		self.parent.thread_register.put(1)
 		RAAR(self.parent, self.beta, self.startiter, self.numiter, self.numiter_relax)
 		self.parent.thread_register.get()
-class Sequence_POER(SequenceBase):
+class Sequence_POER(SequenceBaseMask):
 	def __init__(self, parent, pipelineitem):
-		SequenceBase.__init__(self, parent, pipelineitem)
+		SequenceBaseMask.__init__(self, parent, pipelineitem)
 		if parent.pipeline_started == True:
 			if parent.citer_flow[1] == 2: return;
 			self.StartPhasing()
